/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { Messages } from '@salesforce/core';
import { loglevel, orgApiVersionFlagWithDeprecations, requiredOrgFlagWithDeprecations, SfCommand, } from '@salesforce/sf-plugins-core';
import { CommunityTemplatesResource } from '../../../shared/community/connect/CommunityTemplatesResource.js';
import { ConnectExecutor } from '../../../shared/connect/services/ConnectExecutor.js';
Messages.importMessagesDirectoryFromMetaUrl(import.meta.url);
const messages = Messages.loadMessages('@salesforce/plugin-community', 'template.list');
/**
 * A command to fetch available community templates a community. This is just an sfdx wrapper around
 * the get available community templates connect endpoint
 */
export class CommunityListTemplatesCommand extends SfCommand {
    static deprecateAliases = true;
    static aliases = ['force:community:template:list'];
    static summary = messages.getMessage('summary');
    static description = messages.getMessage('description');
    static examples = messages.getMessages('examples');
    static flags = {
        'target-org': requiredOrgFlagWithDeprecations,
        'api-version': orgApiVersionFlagWithDeprecations,
        loglevel,
    };
    async run() {
        const { flags } = await this.parse(CommunityListTemplatesCommand);
        const listTemplateCommand = new CommunityTemplatesResource();
        return new ConnectExecutor(listTemplateCommand, flags['target-org'].getConnection(flags['api-version']))
            .callConnectApi()
            .then((results) => {
            this.displayResults(results);
            return results;
        });
    }
    displayResults(results) {
        this.table({
            data: results.templates,
            columns: [{ key: 'templateName', name: 'Template Name' }, 'publisher'],
            title: messages.getMessage('response.styledHeader'),
        });
        this.log(messages.getMessage('response.TotalField'), results.total.toString());
    }
}
//# sourceMappingURL=template.js.map