/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { Messages } from '@salesforce/core';
import { Flags, loglevel, orgApiVersionFlagWithDeprecations, requiredOrgFlagWithDeprecations, SfCommand, } from '@salesforce/sf-plugins-core';
import { CommunityPublishResource } from '../../shared/community/connect/CommunityPublishResource.js';
import { ConnectExecutor } from '../../shared/connect/services/ConnectExecutor.js';
Messages.importMessagesDirectoryFromMetaUrl(import.meta.url);
const messages = Messages.loadMessages('@salesforce/plugin-community', 'publish');
/**
 * A command to publish a community. This is just an sfdx wrapper around
 * the community publish connect endpoint
 */
export class CommunityPublishCommand extends SfCommand {
    static deprecateAliases = true;
    static aliases = ['force:community:publish'];
    static summary = messages.getMessage('summary');
    static description = messages.getMessage('description');
    static examples = messages.getMessages('examples');
    static flags = {
        name: Flags.string({
            char: 'n',
            summary: messages.getMessage('flags.name.summary'),
            required: true,
        }),
        'target-org': requiredOrgFlagWithDeprecations,
        'api-version': orgApiVersionFlagWithDeprecations,
        loglevel,
    };
    async run() {
        const { flags } = await this.parse(CommunityPublishCommand);
        const publishCommand = new CommunityPublishResource({
            name: flags.name,
            org: flags['target-org'],
        });
        return new ConnectExecutor(publishCommand, flags['target-org'].getConnection(flags['api-version']))
            .callConnectApi()
            .then((results) => {
            this.displayResults(results);
            return results;
        });
    }
    displayResults(results) {
        this.table({
            data: [results],
            columns: ['id', 'message', 'name', 'status', 'url', 'jobId'],
            title: messages.getMessage('response.styleHeader'),
        });
    }
}
//# sourceMappingURL=publish.js.map