/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { Messages } from '@salesforce/core/messages';
Messages.importMessagesDirectoryFromMetaUrl(import.meta.url);
const messages = Messages.loadMessages('@salesforce/plugin-community', 'create');
const NAME_KEY = 'name';
const JOBID_KEY = 'jobId';
/**
 * A connect api resource for creating a community
 */
export class CommunityCreateResource {
    options;
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    constructor(options) {
        this.options = options;
    }
    // eslint-disable-next-line class-methods-use-this
    handleSuccess(result) {
        const response = {
            message: messages.getMessage('response.createMessage'),
            name: result[NAME_KEY],
            jobId: result[JOBID_KEY],
            action: messages.getMessage('response.action'),
        };
        return response;
    }
    // eslint-disable-next-line class-methods-use-this
    handleError(error) {
        throw error;
    }
    // eslint-disable-next-line class-methods-use-this
    fetchRelativeConnectUrl() {
        return Promise.resolve('/connect/communities');
    }
    // eslint-disable-next-line class-methods-use-this
    getRequestMethod() {
        return 'POST';
    }
    async fetchPostParams() {
        const params = {
            name: this.options.name,
            urlPathPrefix: this.options.urlPathPrefix,
            templateName: this.options.templateName,
            description: this.options.description,
            templateParams: this.options['templateParams'],
        };
        return Promise.resolve(JSON.stringify(params));
    }
}
//# sourceMappingURL=CommunityCreateResource.js.map