/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { URL } from 'node:url';
import { Messages } from '@salesforce/core';
import CommunitiesServices from '../service/CommunitiesServices.js';
Messages.importMessagesDirectoryFromMetaUrl(import.meta.url);
const messages = Messages.loadMessages('@salesforce/plugin-community', 'publish');
export class CommunityPublishResource {
    options;
    info;
    constructor(options) {
        this.options = options;
    }
    async fetchRelativeConnectUrl() {
        return `/connect/communities/${await this.fetchCommunityId()}/publish`;
    }
    // eslint-disable-next-line class-methods-use-this
    getRequestMethod() {
        return 'POST';
    }
    // eslint-disable-next-line class-methods-use-this
    fetchPostParams() {
        return Promise.resolve(JSON.stringify({}));
    }
    handleSuccess(result) {
        return {
            id: result.id,
            message: messages.getMessage('response.message'),
            name: result.name,
            status: this.info?.status,
            url: new URL(result.url).toString(),
            jobId: result.jobId,
        };
    }
    // eslint-disable-next-line class-methods-use-this
    handleError(error) {
        throw error;
    }
    async fetchCommunityId() {
        this.info = await CommunitiesServices.fetchCommunityInfoFromName(this.options.org, this.options.name);
        if (!this.info) {
            throw messages.createError('error.communityNotExists', [this.options.name]);
        }
        return this.info.id;
    }
}
//# sourceMappingURL=CommunityPublishResource.js.map