/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { Messages, SfError } from '@salesforce/core';
Messages.importMessagesDirectoryFromMetaUrl(import.meta.url);
const messages = Messages.loadMessages('@salesforce/plugin-community', 'connect-executor');
/**
 * An executor which calls a connect api for the given org
 */
export class ConnectExecutor {
    connectService;
    connection;
    constructor(connectService, connection) {
        this.connectService = connectService;
        this.connection = connection;
    }
    /**
     * Call the connect resource as defined by the given ConnectResource for the given org
     */
    async callConnectApi() {
        return this.connection
            .request(await this.fetchRequestInfo())
            .then((result) => this.connectService.handleSuccess(result))
            .catch((err) => this.connectService.handleError(err));
    }
    async fetchRequestInfo() {
        const connectUrl = encodeURI(await this.connectService.fetchRelativeConnectUrl());
        const method = this.connectService.getRequestMethod();
        if (method === 'GET') {
            return {
                url: connectUrl,
                method,
                body: null,
            };
        }
        else if (method === 'POST') {
            return {
                url: connectUrl,
                method,
                body: await this.connectService.fetchPostParams(),
            };
        }
        else {
            throw new SfError(messages.getMessage('unsupportedOperation', [method]), 'UNSUPPORTED_OPERATION');
        }
    }
}
//# sourceMappingURL=ConnectExecutor.js.map